package cz.fidentis.analyst.symmetry;

import cz.fidentis.analyst.core.ProgressDialog;
import cz.fidentis.analyst.face.HumanFace;
import javax.swing.SwingWorker;

/**
 * A task that computes symmetry plane from mesh.
 * 
 * @author Radek Oslejsek
 */
public class SymmetryTask extends SwingWorker<Void, Void> {
    
    private SymmetryEstimator symmetryEstimator;
    private HumanFace face;
    private final ProgressDialog progressDialog;
    
    /**
     * Constructor.
     * 
     * @param face Human face
     * @param symmetryEstimator Symmetry estimation algorithm
     * @param progressDialog progress dialogue
     */
    public SymmetryTask(HumanFace face, SymmetryEstimator symmetryEstimator, ProgressDialog progressDialog) {
        this.symmetryEstimator = symmetryEstimator;
        this.face = face;
        this.progressDialog = progressDialog;
    }

    @Override
    protected Void doInBackground() throws Exception {
        face.computeCurvature(false);
        face.getMeshModel().compute(symmetryEstimator);
        face.setSymmetryPlane(symmetryEstimator.getSymmetryPlane());
        return null;
    }
    
    @Override
    protected void done() {
        progressDialog.dispose(); // close progess bar
        if (isCancelled()) {
            face.setSymmetryPlane(null);
        }
    }
}
